<?php

namespace apexl\Io\modules\display\regions;

use apexl\Io\modules\display\components\Content;
use apexl\Io\modules\display\includes\region;

/**
 * @type region
 * Class PageContentRegion
 * @package apexl\Io\modules\display\regions
 */
class ContentRegion extends region
{
    public function setRegionWrapper()
    {
        $this->regionComponent = new Content();
    }
}
