<?php

namespace apexl\Io\modules\display\components;

use apexl\Io\modules\component\entities\componentEntity;

/**
 * @type componentEntity
 * Class ThePageContent
 * @package apexl\Io\modules\display\components
 */
class ThePageContent extends componentEntity
{
    public function __construct()
    {
        parent::__construct();
    }
}
